import psycopg2
from dotenv import load_dotenv
import os

load_dotenv()

DB_USER = os.getenv("DB_USER")
DB_PASSWORD = os.getenv("DB_PASSWORD")
DB_HOST = os.getenv("DB_HOST")
DB_PORT = os.getenv("DB_PORT", 5432)
DB_NAME = os.getenv("DB_NAME")


def get_db():
    conn = psycopg2.connect(
        dbname=DB_NAME, user=DB_USER, password=DB_PASSWORD, host=DB_HOST, port=DB_PORT
    )
    return conn


def create_tables():
    conn = get_db()
    with conn.cursor() as cur:
        cur.execute(
            """
            CREATE TABLE IF NOT EXISTS users (
                id SERIAL PRIMARY KEY,
                telegram_id BIGINT UNIQUE,
                balance BIGINT DEFAULT 0,
                first_name VARCHAR(255),
                last_name VARCHAR(255),
                referrer_id BIGINT,
                click_power INTEGER DEFAULT 1,
                energy_restore_rate FLOAT DEFAULT 1,
                energy INTEGER DEFAULT 1000,
                last_energy_update TIMESTAMP DEFAULT NOW(),  -- Add last_energy_update
                referral_count INTEGER DEFAULT 0,
                auto_clicker_balance INTEGER DEFAULT 0,
                auto_clicker_last_update TIMESTAMP,
                airdrop_claimed BOOLEAN DEFAULT FALSE,  -- Add airdrop_claimed
                premium_reward_claimed BOOLEAN DEFAULT FALSE,
                channel_subscription_rewarded BOOLEAN DEFAULT FALSE,
                channel_boost_rewarded BOOLEAN DEFAULT FALSE,  -- Add channel_boost_rewarded
                discord_rewarded BOOLEAN DEFAULT FALSE,        -- Add social rewards
                twitter_rewarded BOOLEAN DEFAULT FALSE,
                solana_wallet VARCHAR(255)                   -- Add Solana wallet address
            )
        """
        )

        cur.execute(
            """
            CREATE TABLE IF NOT EXISTS upgrades (
                id SERIAL PRIMARY KEY,
                user_id INTEGER REFERENCES users(id),
                upgrade_type VARCHAR(255),
                level INTEGER DEFAULT 1,
                UNIQUE (user_id, upgrade_type)
            )
        """
        )

        cur.execute(
            """
            CREATE TABLE IF NOT EXISTS daily_rewards (
                id SERIAL PRIMARY KEY,
                telegram_id BIGINT UNIQUE,
                current_day INTEGER DEFAULT 1,
                last_claim TIMESTAMP,
                cycle_start DATE    -- Added cycle_start
            )
        """
        )

        cur.execute(
            """
            CREATE TABLE IF NOT EXISTS lottery_claims (
                id SERIAL PRIMARY KEY,
                telegram_id BIGINT UNIQUE,
                last_claim TIMESTAMP,
                next_claim TIMESTAMP
            )
        """
        )

        cur.execute(
            """
            CREATE TABLE IF NOT EXISTS payments (
                id SERIAL PRIMARY KEY,
                user_id BIGINT,
                telegram_payment_charge_id VARCHAR(255),
                amount INTEGER,
                processed BOOLEAN DEFAULT FALSE
            )
        """
        )

        cur.execute(
            """
            CREATE TABLE IF NOT EXISTS boosts (
                id SERIAL PRIMARY KEY,
                channel_id BIGINT,
                user_id BIGINT,
                boost_time TIMESTAMP
            )
            """
        )

        cur.execute(
            """
            CREATE TABLE IF NOT EXISTS user_wallets (
                id SERIAL PRIMARY KEY,
                telegram_id BIGINT UNIQUE,
                seed_phrase_hash TEXT
            )
            """
        )

        conn.commit()
    conn.close()


if __name__ == "__main__":
    create_tables()
