document.addEventListener("DOMContentLoaded", () => {
  // --- Mobile Menu Toggle ---
  const menuToggle = document.querySelector(".menu-toggle");
  const nav = document.querySelector("nav");

  menuToggle.addEventListener("click", () => {
    nav.classList.toggle("active");
  });

  // --- Smooth Scrolling for Navigation Links ---
  document.querySelectorAll('a[href^="#"]').forEach((anchor) => {
    anchor.addEventListener("click", function (e) {
      e.preventDefault();
      nav.classList.remove("active");

      document.querySelector(this.getAttribute("href")).scrollIntoView({
        behavior: "smooth",
      });
    });
  });

  // --- Parallax Effect ---
  window.addEventListener("scroll", () => {
    const scrolled = window.pageYOffset;
    const parallaxElements = document.querySelectorAll(".parallax-element");

    parallaxElements.forEach((el) => {
      const speed = el.dataset.speed;
      el.style.transform = `translateY(${scrolled * speed}px)`;
    });
  });

  // --- Wave Animation ---
  const waves = document.querySelectorAll(".wave");
  waves.forEach((wave, index) => {
    const waveSpeed = 10 + index * 5;
    const waveDelay = index * 2;
    wave.style.animation = `wave ${waveSpeed}s cubic-bezier(0.36, 0.45, 0.63, 0.53) infinite, swell 7s ease -${waveDelay}s infinite`;
  });

  // --- Scroll Animations (Intersection Observer) ---
  const animateOnScroll = (entries, observer) => {
    entries.forEach((entry) => {
      if (entry.isIntersecting) {
        entry.target.classList.add("animate");
        observer.unobserve(entry.target);
      }
    });
  };

  const observer = new IntersectionObserver(animateOnScroll, {
    threshold: 0.1,
  });

  document
    .querySelectorAll(".tokenomics-card, .roadmap-item, .social-card")
    .forEach((element) => {
      observer.observe(element);
    });

  // --- Tilt Effect (VanillaTilt.js) ---
  VanillaTilt.init(document.querySelectorAll(".tokenomics-card"), {
    max: 25,
    speed: 400,
    glare: true,
    "max-glare": 0.5,
  });

  // --- Coin Flip Animation ---
  const coin = document.querySelector(".coin");
  coin.addEventListener("click", () => {
    coin.classList.toggle("flipped");
  });

  // --- Trump Whale Image Movement ---
  const whale = document.querySelector(".trump-whale img");
  let lastScrollTop = 0;

  window.addEventListener("scroll", () => {
    let st = window.pageYOffset || document.documentElement.scrollTop;

    whale.style.top = st * 0.7 + "px";

    lastScrollTop = st <= 0 ? 0 : st;
  });

  // --- Bubble Animation ---
  const bubbleContainer = document.querySelector(".bubble-container");

  function createBubble() {
    const bubble = document.createElement("div");
    bubble.classList.add("bubble");

    const size = Math.random() * 60 + 20;
    bubble.style.width = `${size}px`;
    bubble.style.height = `${size}px`;

    bubble.style.left = `${Math.random() * 100}%`;
    bubble.style.animationDuration = `${Math.random() * 2 + 4}s`;

    document.querySelector(".bubble-container").appendChild(bubble);

    setTimeout(() => bubble.remove(), 6000);
  }

  setInterval(createBubble, 300);

  // --- Particle.js Configuration ---
  particlesJS("particles-js", {
    particles: {
      number: { value: 80, density: { enable: true, value_area: 800 } },
      color: { value: "#ffffff" },
      shape: {
        type: "circle",
        stroke: { width: 0, color: "#000000" },
        polygon: { nb_sides: 5 },
        image: { src: "img/coin.png", width: 100, height: 100 },
      },
      opacity: {
        value: 0.5,
        random: false,
        anim: { enable: false, speed: 1, opacity_min: 0.1, sync: false },
      },
      size: {
        value: 3,
        random: true,
        anim: { enable: false, speed: 40, size_min: 0.1, sync: false },
      },
      line_linked: {
        enable: true,
        distance: 150,
        color: "#ffffff",
        opacity: 0.4,
        width: 1,
      },
      move: {
        enable: true,
        speed: 6,
        direction: "none",
        random: false,
        straight: false,
        out_mode: "out",
        bounce: false,
        attract: { enable: false, rotateX: 600, rotateY: 1200 },
      },
    },
    interactivity: {
      detect_on: "canvas",
      events: {
        onhover: { enable: true, mode: "repulse" },
        onclick: { enable: true, mode: "push" },
        resize: true,
      },
      modes: {
        grab: { distance: 400, line_linked: { opacity: 1 } },
        bubble: { distance: 400, size: 40, duration: 2, opacity: 8, speed: 3 },
        repulse: { distance: 200, duration: 0.4 },
        push: { particles_nb: 4 },
        remove: { particles_nb: 2 },
      },
    },
    retina_detect: true,
  });

  // --- Roadmap Animation (Intersection Observer) ---
  const roadmapItems = document.querySelectorAll(".roadmap-item");

  document
    .querySelectorAll(".roadmap-item, .tokenomics-card, .social-card")
    .forEach((el) => {
      observer.observe(el);
    });
});
